@@ -28,7 +28,8 @@ abline(-g_constraint@bias/w2[2],-w2[1]/w2[2],lty=1,col="green")
 abline(-g_noconstraint@bias/w3[2],-w3[1]/w3[2],lty=1,col="red")
 abline(-w4[1]/w4[3],-w4[2]/w4[3],lty=1,lwd=3,col="blue")
 
-# As example
+# An example
+set.seed(42)
 data <- generateSlicedCookie(200,expected=TRUE,gap=1)
 X <- model.matrix(Class~.-1,data)
 y <- factor(data$Class)
@@ -41,41 +42,41 @@ X_u <- problem$X_u
 y_e <- unlist(list(problem$y,problem$y_u))
 Xe<-rbind(X,X_u)
 
-g_sup <- SVM(X,y,scale=FALSE)
+g_sup <- SVM(X,y,x_center=FALSE,scale=FALSE,C = 10)
 g_constraint <- TSVM(X=X,y=y,X_u=X_u,
-                     C=1,Cstar=0.1,balancing_constraint = TRUE,
+                     C=10,Cstar=10,balancing_constraint = TRUE,
                      x_center = FALSE,verbose=TRUE)
 
 g_noconstraint <- TSVM(X=X,y=y,X_u=X_u,
-                       C=10,Cstar=0.001,balancing_constraint = FALSE,
+                       C=10,Cstar=10,balancing_constraint = FALSE,
                        x_center = FALSE,verbose=TRUE)
 
-g_lin <- LinearTSVM(X=X,y=y,X_u=X_u,C=10,Cstar=0.001,
+g_lin <- LinearTSVM(X=X,y=y,X_u=X_u,C=10,Cstar=10,
                     verbose=TRUE,x_center = FALSE)
 
 g_oracle <- SVM(Xe,y_e,scale=FALSE)
 
-w1 <- g_sup@alpha %*% X
+w1 <- c(g_sup@bias,g_sup@alpha %*% X)
 w2 <- c(g_constraint@bias,g_constraint@alpha %*% rbind(X,X_u,X_u,colMeans(X_u)))
 w3 <- c(g_noconstraint@bias,g_noconstraint@alpha %*% rbind(X,X_u,X_u))
 w4 <- g_lin@w
-w5 <- g_oracle@alpha %*% Xe
+w5 <- c(g_oracle@bias, g_oracle@alpha %*% Xe)
 print(sum(abs(w4-w3)))
 
 plot(X[,1],X[,2],col=factor(y),asp=1,ylim=c(-3,3))
 points(X_u[,1],X_u[,2],col="darkgrey",pch=16,cex=1)
-abline(-g_sup@bias/w1[2],-w1[1]/w1[2],lty=2)
-abline(((1-g_sup@bias)/w1[2]),-w1[1]/w1[2],lty=2) # +1 Margin
-abline(((-1-g_sup@bias)/w1[2]),-w1[1]/w1[2],lty=2) # -1 Margin
+abline(-w1[1]/w1[3],-w1[2]/w1[3],lty=2)
+abline(((1-w1[1])/w1[3]),-w1[2]/w1[3],lty=2) # +1 Margin
+abline(((-1-w1[1])/w1[3]),-w1[2]/w1[3],lty=2) # -1 Margin
 
 # Oracle:
-abline(-g_oracle@bias/w5[2],-w5[1]/w5[2],lty=1,col="purple")
+abline(-w5[1]/w5[3],-w5[2]/w5[3],lty=1,col="purple")
 
 # With balancing constraint:
-abline(-g_constraint@bias/w2[2],-w2[1]/w2[2],lty=1,col="green")
-
-# Without balancing constraint:
-abline(-g_noconstraint@bias/w3[2],-w3[1]/w3[2],lty=1,col="red")
+abline(-w2[1]/w2[3],-w2[2]/w2[3],lty=1,col="green")
 
 # Linear TSVM implementation (no constraint):
 abline(-w4[1]/w4[3],-w4[2]/w4[3],lty=1,lwd=3,col="blue") 
+
+# Without balancing constraint:
+abline(-w3[1]/w3[3],-w3[2]/w3[3],lty=1,col="red")
